@@ -1,8 +1,8 @@
 #ifndef OBGNOME_APP_H
 #define OBGNOME_APP_H 1
 
+#include <gnome.h>
 #include "obgtk/obgtk.h"
-#include "gnome.h"
 
 @interface Gnome_App : Gtk_App
 - initApp:(char *)app_id
