@@ -11,6 +11,11 @@
 - init;
 - castGtkButton:(GtkButton *) castitem;
 - initWithLabel:(gchar *) label;
+- pressed;
+- released;
+- clicked;
+- enter;
+- leave;
 @end
 
 #endif /* OBGTK_BUTTON_H */
