@@ -23,7 +23,7 @@
 - set_column_title:(gint) column
 		  :(gchar *) title;
 - set_column_widget:(gint) column
-		   :(Gtk_Widget *) widget;
+		   :(id) widget;
 - set_column_justification:(gint) column
 			  :(GtkJustification) justification;
 - set_column_width:(gint) column
@@ -57,15 +57,40 @@
 - (gint)appendCListRow:(gchar **) text;
 - insertCListRow:(gchar **) text
 		:(gint) row;
-- remove:(gint) row;
+- removeCListRow:(gint) row;
 - set_row_data:(gint) row
-	      :(gpointer) data;
+       rowData:(gpointer) data;
+- set_row_data_full:(gint) row
+	    rowData:(gpointer) data
+    destroyCallback:(GtkDestroyNotify) destroy;
 - (gpointer) get_row_data:(gint) row;
-- select_row:(gint) row
-	    :(gint) column;
-- unselect_row:(gint) row
-	      :(gint) column;
+- (gint) find_row_from_data:(gpointer) data;
+- select_row:(gint) row :(gint) column;
+- unselect_row:(gint) row :(gint) column;
 - clear;
+
+- column_titles_show;
+- column_titles_hide;
+- column_title_active:(gint) column;
+- column_title_passive:(gint) column;
+- column_titles_active;
+- column_titles_passive;
+- (GtkVisibility) row_is_visible:(gint) row;
+- (GtkCellType) get_cell_type:(gint) row :(gint) column;
+- (gint)get_text:(gint) row
+		:(gint) column
+	 getText:(gchar **) text;
+- (gint) get_pixmap:(gint) row :(gint) column
+	  getPixmap:(GdkPixmap **) pixmap
+	    getMask:(GdkBitmap **) mask;
+- (gint) get_pixtext:(gint) row :(gint) column
+	     getText:(gchar **) text
+	  getSpacing:(guint8 *) spacing
+	  getPixmap:(GdkPixmap **) pixmap
+	    getMask:(GdkBitmap **) mask;
+- (gint) get_selection_info:(gint) x :(gint) y
+		     getRow:(gint *) row
+		  getColumn:(gint *) column;
 @end
 
 #endif /* OBGTK_CLIST_H */
