@@ -158,14 +158,22 @@
   return self;
 }
 
-- remove:(gint) row
+- removeCListRow:(gint) row
 {
   gtk_clist_remove(gtkclist, row);
   return self;
 }
 
+- set_row_data_full:(gint) row
+	    rowData:(gpointer) data
+    destroyCallback:(GtkDestroyNotify) destroy
+{
+  gtk_clist_set_row_data_full(gtkclist, row, data, destroy);
+  return self;
+}
+
 - set_row_data:(gint) row
-	      :(gpointer) data
+       rowData:(gpointer) data
 {
   gtk_clist_set_row_data(gtkclist, row, data);
   return self;
@@ -195,4 +203,84 @@
   gtk_clist_clear(gtkclist);
   return self;
 }
+
+
+- column_titles_show
+{
+  return self;
+}
+
+- column_titles_hide;
+{
+  return self;
+}
+
+- column_title_active:(gint) column;
+{
+  gtk_clist_column_title_active(gtkclist, column);
+  return self;
+}
+
+- column_title_passive:(gint) column;
+{
+  gtk_clist_column_title_passive(gtkclist, column);
+  return self;
+}
+
+- column_titles_active
+{
+  gtk_clist_column_titles_active(gtkclist);
+  return self;
+}
+
+- column_titles_passive
+{
+  gtk_clist_column_titles_passive(gtkclist);
+  return self;
+}
+
+- (GtkVisibility) row_is_visible:(gint) row
+{
+  return gtk_clist_row_is_visible(gtkclist, row);
+}
+
+- (GtkCellType) get_cell_type:(gint) row :(gint) column
+{
+  return gtk_clist_get_cell_type(gtkclist, row, column);
+}
+
+- (gint)get_text:(gint) row
+		:(gint) column
+	 getText:(gchar **) text
+{
+  return gtk_clist_get_text(gtkclist, row, column, text);
+}
+
+- (gint) get_pixmap:(gint) row :(gint) column
+	  getPixmap:(GdkPixmap **) pixmap
+	    getMask:(GdkBitmap **) mask
+{
+  return gtk_clist_get_pixmap(gtkclist, row, column, pixmap, mask);
+}
+
+- (gint) get_pixtext:(gint) row :(gint) column
+	     getText:(gchar **) text
+	  getSpacing:(guint8 *) spacing
+	  getPixmap:(GdkPixmap **) pixmap
+	    getMask:(GdkBitmap **) mask
+{
+  return gtk_clist_get_pixtext(gtkclist, row, column, text, spacing, pixmap, mask);
+}
+
+- (gint) get_selection_info:(gint) x :(gint) y
+		     getRow:(gint *) row
+		  getColumn:(gint *) column
+{
+  return gtk_clist_get_selection_info(gtkclist, x, y, row, column);
+}
+
+- (gint) find_row_from_data:(gpointer) data
+{
+  return gtk_clist_find_row_from_data(gtkclist, data);
+}
 @end
