@@ -12,8 +12,8 @@
 - castGtkEditable:(GtkEditable *) castitem;
 - select_region:(gint) start :(gint) end;
 - insert_text:(const gchar *) new_text
-	     :(gint) new_text_length
-	     :(gint *) position;
+      textLen:(gint) new_text_length
+ textPosition:(gint *) position;
 - delete_text:(gint) start_pos
 	     :(gint) end_pos;
 - (gchar *) get_chars:(gint) start_pos
