@@ -14,8 +14,8 @@
 }
 
 - insert_text:(const gchar *) new_text
-	     :(gint) new_text_length
-	     :(gint *) position
+      textLen:(gint) new_text_length
+ textPosition:(gint *) position
 {
   gtk_editable_insert_text(gtkeditable, new_text, new_text_length, position);
   return self;
@@ -69,4 +69,6 @@
   gtk_editable_changed(gtkeditable);
   return self;
 }
+
+
 @end
