@@ -11,9 +11,9 @@
 }
 - castGtkEntry:(GtkEntry *) castitem;
 - initWithMaxLength:(guint16) max_length;
-- set_text:(gchar *) text;
-- append_text:(gchar *) text;
-- prepend_text:(gchar *) text;
+- set_text:(const gchar *) text;
+- append_text:(const gchar *) text;
+- prepend_text:(const gchar *) text;
 - set_position:(gint) position;
 - (gchar *) get_text;
 - set_visibility:(BOOL) visible;
