@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkItem.h"
 
 @implementation Gtk_Item
 - castGtkItem:(GtkItem *)castitem;
