@@ -13,18 +13,21 @@
 @public
   GtkMenu *gtkmenu;
 }
-- init;
 - castGtkMenu:(GtkMenu *) castitem;
-- popup     :(Gtk_MenuShell *) parent_menu_shell
-    menuItem:(Gtk_MenuItem *) parent_menu_item
+- popup     :(id) parent_menu_shell
+    menuItem:(id) parent_menu_item
      posFunc:(GtkMenuPositionFunc) func
  posFuncData:(gpointer) data
   posFuncBtn:(gint) button
  posFuncTime:(guint32) activate_time;
 - popdown;
-- (Gtk_Widget *) get_active;
+- (id) get_active;
 - set_active:(gint) index;
-- set_accelerator_table:(Gtk_AcceleratorTable *) table;
+- set_accelerator_table:(id) table;
+- attach_to_widget:(id) attach_widget
+    detachFunction:(GtkMenuDetachFunc) detacher;
+- (id) get_attach_widget;
+- detach;
 @end
 
 #endif /* OBGTK_MENU_H */
