@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkMenu.h"
 
 @implementation Gtk_Menu
 - castGtkMenu:(GtkMenu *) castitem
@@ -39,8 +39,8 @@
   posFuncBtn:(gint) button
  posFuncTime:(guint32) activate_time
 {
-  gtk_menu_popup(gtkmenu, parent_menu_shell->gtkwidget,
-		 parent_menu_item->gtkwidget, func, data,
+  gtk_menu_popup(gtkmenu, parent_menu_shell?parent_menu_shell->gtkwidget:NULL,
+		 parent_menu_item?parent_menu_item->gtkwidget:NULL, func, data,
 		 button, activate_time);
   return self;
 }
@@ -67,4 +67,22 @@
   gtk_menu_set_accelerator_table(gtkmenu, table->gtkacceleratortable);
   return self;
 }
+
+- attach_to_widget:(id) attach_widget
+    detachFunction:(GtkMenuDetachFunc) detacher
+{
+  gtk_menu_attach_to_widget(gtkmenu, GTK_WIDGET([attach_widget getGtkObject]), detacher);
+  return self;
+}
+
+- (id) get_attach_widget
+{
+  return (id)gtk_object_get_data_by_id(GTK_OBJECT(gtk_menu_get_attach_widget(gtkmenu)), OBJC_ID());
+}
+
+- detach
+{
+  gtk_menu_detach(gtkmenu);
+  return self;
+}
 @end
