@@ -2,18 +2,18 @@
 #define OBGTK_MENU_ITEM_H 1
 
 #include <obgtk/obgtkItem.h>
-#include <obgtk/obgtkMenu.h>
 #include <gtk/gtkmenuitem.h>
 
+@class Gtk_Menu;
+
 @interface Gtk_MenuItem : Gtk_Item
 {
 @public
   GtkMenuItem *gtkmenuitem;
 }
 - castGtkMenuItem:(GtkMenuItem *) castitem;
-- init;
 - initWithLabel:(gchar *) label;
-- set_submenu:(Gtk_Menu *) submenu;
+- set_submenu:(id) submenu;
 - set_placement:(GtkSubmenuPlacement) placement;
 - accelerator_size;
 - accelerator_text:(gchar *)buffer;
@@ -22,6 +22,7 @@
 - select;
 - deselect;
 - activate;
+- right_justify;
 @end
 
 #endif /* OBGTK_MENU_ITEM_H */
