@@ -10,9 +10,9 @@
 @public
   GtkOptionMenu *gtkoptionmenu;
 }
-- init;
-- (Gtk_Menu *) get_menu;
-- set_menu:(Gtk_Menu *) menu;
+- castGtkOptionMenu:(GtkOptionMenu *) castitem;
+- (id) get_menu;
+- set_menu:(id) gtk_menu;
 - remove_menu;
 - set_history:(gint) index;
 @end
