@@ -11,8 +11,13 @@
 }
 - initWithRadioGroup:(GSList *) group;
 - initWithRadioGroupLabel:(GSList *) group
- aLabel:(gchar *) label;
+		    label:(const gchar *) label;
+- castGtkRadioButton:(GtkRadioButton *) castitem;
+- initWithRadioWidget:(id) gtk_radio;
+- initWithRadioWidgetLabel:(id) gtk_radio
+		     label:(const gchar *) label;
 - (GSList *) group;
+- set_group:(GSList *) group;
 @end
 
 #endif /* OBGTK_RADIO_BUTTON_H */
