@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkRuler.h"
 
 @implementation Gtk_Ruler
 - castGtkRuler:(GtkRuler *)castitem
