@@ -17,7 +17,7 @@
   return gtk_vbutton_box_get_spacing_default();
 }
 
-- (gint) get_layout_default
+- (GtkButtonBoxStyle) get_layout_default
 {
   return gtk_vbutton_box_get_layout_default();
 }
@@ -28,7 +28,7 @@
   return self;
 }
 
-- set_layout_default:(gint) layout
+- set_layout_default:(GtkButtonBoxStyle) layout
 {
   gtk_vbutton_box_set_layout_default(layout);
   return self;
