@@ -6,7 +6,7 @@
 #include <gtk/gtkvscrollbar.h>
 
 @interface Gtk_VScrollbar : Gtk_Scrollbar
-- initWithGtkAdjustment:(Gtk_Adjustment *) adjustment;
+- initWithGtkAdjustment:(id) adjustment;
 @end
 
 #endif /* OBGTK_VSCROLLBAR_H */
