@@ -2,9 +2,10 @@
 #define OBGTK_WIDGET_H 1
 
 #include <obgtk/obgtkObject.h>
-#include <obgtk/obgtkAcceleratorTable.h>
 #include <gtk/gtkwidget.h>
 
+@class Gtk_AcceleratorTable;
+
 @interface Gtk_Widget : Gtk_Object
 {
 @public
@@ -45,8 +46,8 @@
 - set_sensitive:(gint)sensitive;
 - set_parent:(Gtk_Widget *) parent;
 - set_style:(GtkStyle *) style;
-- set_uposition: locX:(gint)x
-	   locY:(gint)y;
+- set_uposition:(gint)x
+	       :(gint)y;
 - set_usize:(gint) awidth
      height:(gint) aheight;
 - set_events:(gint) events;
