@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkWindow.h"
 
 @implementation Gtk_Window
 - castGtkWindow:(GtkWindow *) castitem
